@@ -57,7 +57,8 @@ void GroupedAppletsContainer::ensureSystrayExists()
 
     uint id = config().readEntry("ContainmentId", 0);
     if (id > 0) {
-        foreach (Plasma::Containment *candidate, c->containments()) {
+        const auto containments = c->containments();
+        for (Plasma::Containment *candidate : containments) {
             if (candidate->id() == id) {
                 m_innerContainment = candidate;
                 break;
@@ -83,11 +84,11 @@ void GroupedAppletsContainer::ensureSystrayExists()
     m_innerContainment->setLocation(location());
 
     m_internalContainmentItem = m_innerContainment->property("_plasma_graphicObject").value<QQuickItem *>();
-    emit internalContainmentItemChanged();
+    Q_EMIT internalContainmentItemChanged();
 
     actions()->addAction(QStringLiteral("configure"), m_innerContainment->actions()->action(QStringLiteral("configure")));
     connect(m_innerContainment.data(), &Plasma::Containment::configureRequested, this, [this](Plasma::Applet *applet) {
-        emit containment()->configureRequested(applet);
+        Q_EMIT containment()->configureRequested(applet);
     });
 
     if (m_internalContainmentItem) {
