@@ -52,7 +52,8 @@ void GroupingContainment::newTask(const QString &task)
 
 void GroupingContainment::cleanupTask(const QString &task)
 {
-    foreach (Plasma::Applet *applet, applets()) {
+    const auto appletList = applets();
+    for (Plasma::Applet *applet : appletList) {
         if (!applet->pluginMetaData().isValid() || task == applet->pluginMetaData().pluginId()) {
             applet->destroy();
         }
@@ -79,8 +80,9 @@ void GroupingContainment::showPlasmoidMenu(QQuickItem *appletInterface, int x, i
     connect(this, &QObject::destroyed, desktopMenu, &QMenu::close);
     desktopMenu->setAttribute(Qt::WA_DeleteOnClose);
 
-    emit applet->contextualActionsAboutToShow();
-    foreach (QAction *action, applet->contextualActions()) {
+    Q_EMIT applet->contextualActionsAboutToShow();
+    const QList<QAction *> actions = applet->contextualActions();
+    for (QAction *action : actions) {
         if (action) {
             desktopMenu->addAction(action);
         }
